/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: ClientClusteredObjectView.java 2170 2008-10-14 19:54:48Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.client;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Set;

import javax.ejb.EJBObject;

import org.ow2.cmi.controller.common.ImmutableClusteredObjectInfos;
import org.ow2.cmi.lb.data.PolicyData;
import org.ow2.cmi.reference.CMIReference;

/**
 * @author Loris Bouzonnet
 */
public class ClientClusteredObjectView extends ImmutableClusteredObjectInfos {

    /**
     *
     */
    private static final long serialVersionUID = 5415780538195796182L;

    public ClientClusteredObjectView(
            final String clusterName,
            final boolean proxyEnabled,
            final String objectName,
            final String itfName,
            final String businessName,
            final boolean stateful,
            final Set<String> applicationExceptionNames) {
        super(clusterName, proxyEnabled, objectName, itfName,
                businessName, stateful, applicationExceptionNames);
    }

    private List<CMIReference> refs;

    private boolean replicated;

    private PolicyData policyData;

    private Class<?> itfClass;

    public void setItfClass(final Class<?> itfClass) {
        this.itfClass = itfClass;
    }

    public void setBusinessClass(final Class<? extends EJBObject> businessClass) {
        this.businessClass = businessClass;
    }

    public Class<?> getItfClass() {
        return itfClass;
    }

    public Class<? extends EJBObject> getBusinessClass() {
        return businessClass;
    }

    private Class<? extends EJBObject> businessClass;

    public void setPolicyData(final PolicyData policyData) {
        this.policyData = policyData;
    }

    public PolicyData getPolicyData() {
        return policyData;
    }

    public void setCMIReferences(final Collection<CMIReference> cmiReferences) {
        this.refs = new ArrayList<CMIReference>(cmiReferences);
    }

    public List<CMIReference> getCMIReferences() {
        return new ArrayList<CMIReference>(refs);
    }

    public boolean isReplicated() {
        return replicated;
    }

    public void setReplicated(final boolean replicated) {
        this.replicated = replicated;
    }

    @Override
    public boolean equals(final Object object) {
        if(object == null || !(object instanceof ClientClusteredObjectView)) {
            return false;
        }
        ClientClusteredObjectView clientClusteredObjectView =
            (ClientClusteredObjectView) object;
        return super.equals(clientClusteredObjectView)
            && clientClusteredObjectView.replicated == replicated
            && refs.equals(clientClusteredObjectView.refs)
            && policyData.equals(clientClusteredObjectView.policyData)
            && itfClass.equals(clientClusteredObjectView.itfClass);
    }

    @Override
    public int hashCode() {
        return 7*(super.hashCode() + 31*(Boolean.valueOf(replicated).hashCode()
            + 31*(refs.hashCode() + 31*(policyData.hashCode() + 31*itfClass.hashCode()))));
    }
}
